@@ -50,6 +50,7 @@
 
 #ifndef WT_TARGET_JAVA
 #include "EntryPoint.h"
+#include "EntryPointManager.h"
 #endif // WT_TARGET_JAVA
 
 namespace boost {
@@ -66,36 +67,13 @@ namespace Wt {
   class WLogger;
   class WServer;
 
-#ifndef WT_TARGET_JAVA
-
-/// A segment in the deployment path of an entry point,
-/// used for routing.
-struct WT_API PathSegment {
-  PathSegment()
-    : parent(nullptr),
-      entryPoint(nullptr)
-  { }
-
-  PathSegment(const std::string &s,
-              PathSegment *p)
-    : parent(p),
-      entryPoint(nullptr),
-      segment(s)
-  { }
-
-  PathSegment *parent;
-  const EntryPoint *entryPoint;
-  std::vector<std::unique_ptr<PathSegment>> children; // Static path segments
-  std::unique_ptr<PathSegment> dynamicChild; // Dynamic path segment, lowest priority
-  std::string segment;
-};
-
-#endif // WT_TARGET_JAVA
-
 class WT_API HeadMatter {
 public:
   HeadMatter(std::string contents,
-             std::string userAgent);
+             std::string userAgent)
+    : contents_(contents),
+      userAgent_(userAgent)
+  { }
 
   const std::string& contents() const { return contents_; }
   const std::string& userAgent() const { return userAgent_; }
@@ -111,11 +89,16 @@ public:
              std::string contents)
     : name_(name),
       contents_(contents)
-{ }
+  { }
 
   const std::string& contents() const { return contents_; }
   const std::string& name() const { return name_; }
 
+  bool operator==(const HttpHeader& other) const
+  {
+    return contents_ == other.contents() && name_ == other.name();
+  }
+
 private:
   std::string name_;
   std::string contents_;
@@ -180,10 +163,11 @@ public:
   void setSessionIdPrefix(const std::string& prefix);
 
 #ifndef WT_TARGET_JAVA
-  void addEntryPoint(const EntryPoint& entryPoint);
-  bool tryAddResource(const EntryPoint& entryPoint); // Returns bool indicating success:
+  void addEntryPoint(const std::shared_ptr<const EntryPoint>& entryPoint);
+  bool tryAddResource(const std::shared_ptr<const EntryPoint>& entryPoint); // Returns bool indicating success:
                                                      // false if entry point existed already
   void removeEntryPoint(const std::string& path);
+  void removeResource(const WResource* resource);
   void setDefaultEntryPoint(const std::string& path);
   // Returns matching entry point and match length
   EntryPointMatch matchEntryPoint(const std::string &scriptName,
@@ -284,6 +268,9 @@ public:
   bool useScriptNonce() const;
   bool delayLoadAtBoot() const;
   bool useXFrameSameOrigin() const;
+  bool servePrivateResourcesToBots() const;
+  std::string botResourcesPath() const;
+  int maxAutoRemovablePublicResources() const;
 
   bool agentIsBot(const std::string& agent) const;
   bool agentSupportsAjax(const std::string& agent) const;
@@ -327,9 +314,7 @@ private:
   std::string uaCompatible_;
 
 #ifndef WT_TARGET_JAVA
-  EntryPointList entryPoints_;
-  PathSegment rootPathSegment_; /// The toplevel path segment ('/') for routing,
-                                /// root of the rounting tree.
+  EntryPointManager entryPointManager_;
 #endif // WT_TARGET_JAVA
 
   SessionPolicy   sessionPolicy_;
@@ -356,6 +341,8 @@ private:
   PropertyMap     properties_;
   bool            xhtmlMimeType_;
   bool            behindReverseProxy_;
+  bool            servePrivateResourcesToBots_;
+  std::string     botResourcesPath_;
 
   // trusted-proxy-config
   std::string     originalIPHeader_;
@@ -396,13 +383,6 @@ private:
   void readApplicationSettings(Wt::rapidxml::xml_node<char> *app);
   void readConfiguration(bool silent);
   WLogEntry log(const std::string& type) const;
-
-  // Add the given entryPoint to the routing tree
-  // NOTE: Server may not be running, or WRITE_LOCK should
-  // be grabbed before registerEntryPoint is invoked.
-  // This is to be used by the other entry point functions
-  // (addEntryPoint, tryAddResource, removeEntryPoint,...)
-  void registerEntryPoint(const EntryPoint &entryPoint);
 };
 
 }
